#[non_exhaustive]pub enum RustDistError {
AwsError(AwsError),
ChannelNotAvailable(Channel),
ChunkMetadataMissing,
ChunkWriteFlushError(IntoInnerError<BufWriter<Vec<u8>>>),
Io(Error),
BaseCacheDir(BaseCacheDirError),
IsStale(IsStaleError),
UnrecognizedText(Utf8Error),
UnableToParseVersionNumberComponent(&'static &'static str, String),
}Expand description
Top level failure cases for rust-releases-rust-dist source crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AwsError(AwsError)
Returned in case of an error related to the AWS SDK
ChannelNotAvailable(Channel)
Returned in case a Channel is not available for the Source.
ChunkMetadataMissing
Returned when the AWS Object returned does not have meta data. In such case we can’t get path of the object which we use to determine the release version.
ChunkWriteFlushError(IntoInnerError<BufWriter<Vec<u8>>>)
Returned when we can’t consume the inner in-memory buffered writer.
Io(Error)
Returned in case of an i/o error.
BaseCacheDir(BaseCacheDirError)
Returned in case of the base cache folder could not be found.
IsStale(IsStaleError)
Returned when the staleness check fails.
UnrecognizedText(Utf8Error)
Returned in case the input text cannot be parsed.
UnableToParseVersionNumberComponent(&'static &'static str, String)
Returned in case a component of a semver version could not be parsed as a number.
The component is usually the major, minor or patch version.